@@ -1,6 +1,6 @@
 import requests
 
-from exceptions import *
+from exceptions import FacepyError
 
 try:
     import simplejson as json
@@ -185,7 +185,7 @@ class GraphAPI(object):
 
         try:
             data = json.loads(data)
-        except ValueError as e:
+        except ValueError:
             return data
 
         # Facebook's Graph API sometimes responds with 'true' or 'false'. Facebook offers no documentation
